Jobrunner
=========

Jobrunner is a minimal command line tool to manage and deploy computing jobs and organize your directories. Created because I cannot do anything without organizing it first.

Examples:

`Channel Flow <https://github.com/akashdhruv/channel-flow-container>`_

`Nucleate Boiling <https://github.com/akashdhruv/nucleate-boiling>`_

Install in development mode
---------------------------

::

   cd jobrunner
   python3 setup.py develop --user
